fnss.adapters.jfed.from_jfed — FNSS 0.7.0 documentation

# fnss.adapters.jfed.from_jfed

`from_jfed`(path)

  Read a jFed RSPEC file and returns an FNSS topology modelling the network topology of the jFed experiment specification.

  Parameters: | path : str The path of the jFed RSPEC file to parse
  Returns: | topology: Topology The parsed topology

  Notes

  This function does not support directed topologies and unidirectional links

  It is possible in jFed to create multipoint links (links with more than 2 endpoints). Such types of link cannot be modelled in FNSS. Therefore, any attempt to convert an RSPEC with such links will fail.